==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/sv-SE/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Bekräfta storlekar för borttagning av bulk',
  'bulk_delete_help'	=> 'Granska tillgångarna för delad borttagning nedan. En gång raderas kan dessa tillgångar återställas, men de kommer inte längre att vara associerade med några användare de tilldelas för närvarande.',
  'bulk_delete_warn'	=> 'Du håller på att ta bort: asset_count-tillgångar.',
	'bulk_update'		=> 'Bulk Update Assets',
	'bulk_update_help'	=> 'I det här formuläret kan du uppdatera flera tillgångar på en gång. Fyll bara i de fält du behöver ändra. Alla fält som lämnas tomma kommer att förbli oförändrade.',
	'bulk_update_warn'	=> 'Du håller på att redigera egenskaperna hos: asset_count-tillgångar.',
    'checkedout_to'		=> 'Utcheckad till',
    'checkout_date'		=> 'Utcheckningsdatum',
    'checkin_date'		=> 'Incheckningsdatum',
    'checkout_to'		=> 'Checka ut till',
    'cost'				=> 'Inköpskostnad',
    'create'			=> 'Skapa Tillgång',
    'date'				=> 'Köpdatum',
    'depreciation'	    => 'Avskrivning',
    'depreciates_on'	=> 'Depreciates On',
    'default_location'	=> 'Standard plats',
    'eol_date'			=> 'EOL Datum',
    'eol_rate'			=> 'EOL-hastighet',
    'expected_checkin'  => 'Förväntad incheckningsdatum',
    'expires'			=> 'Förfaller',
    'fully_depreciated'	=> 'Helt avskrivna',
    'help_checkout'		=> 'Om du vill tilldela denna tillgång omedelbart, välj "Redo att distribuera" från statuslistan ovan. ',
    'mac_address'		=> 'MAC-adress',
    'manufacturer'		=> 'Tillverkare',
    'model'				=> 'Modell',
    'months'			=> 'månader',
    'name'				=> 'Asset Name',
    'notes'				=> 'Anteckningar',
    'order'				=> 'Order Nummer',
    'qr'				=> 'QR-kod',
    'requestable'		=> 'Användare kan begära denna tillgång',
    'select_statustype'	=> 'Välj Statustyp',
    'serial'			=> 'Serienummer',
    'status'			=> 'Status',
    'tag'				=> 'Asset Tag',
    'update'			=> 'Asset Update',
    'warranty'			=> 'Garanti',
		'warranty_expires'		=> 'Garantin löper ut',
    'years'				=> 'år',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/sv-SE/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Bekräfta storlekar för borttagning av bulk',
  'bulk_delete_help'	=> 'Granska tillgångarna för delad borttagning nedan. En gång raderas kan dessa tillgångar återställas, men de kommer inte längre att vara associerade med några användare de tilldelas för närvarande.',
  'bulk_delete_warn'	=> 'Du håller på att ta bort: asset_count-tillgångar.',
    'bulk_update'		=> 'Bulk Update Assets',
    'bulk_update_help'	=> 'I det här formuläret kan du uppdatera flera tillgångar på en gång. Fyll bara i de fält du behöver ändra. Alla fält som lämnas tomma kommer att förbli oförändrade.',
    'bulk_update_warn'	=> 'Du håller på att redigera egenskaperna hos: asset_count-tillgångar.',
    'checkedout_to'		=> 'Utcheckad till',
    'checkout_date'		=> 'Utcheckningsdatum',
    'checkin_date'		=> 'Incheckningsdatum',
    'checkout_to'		=> 'Checka ut till',
    'cost'				=> 'Inköpskostnad',
    'create'			=> 'Skapa Tillgång',
    'date'				=> 'Köpdatum',
    'depreciation'	    => 'Avskrivning',
    'depreciates_on'	=> 'Depreciates On',
    'default_location'	=> 'Standard plats',
    'eol_date'			=> 'EOL Datum',
    'eol_rate'			=> 'EOL-hastighet',
    'expected_checkin'  => 'Förväntad incheckningsdatum',
    'expires'			=> 'Förfaller',
    'fully_depreciated'	=> 'Helt avskrivna',
    'help_checkout'		=> 'Om du vill tilldela denna tillgång omedelbart, välj "Redo att distribuera" från statuslistan ovan. ',
    'mac_address'		=> 'MAC-adress',
    'manufacturer'		=> 'Tillverkare',
    'model'				=> 'Modell',
    'months'			=> 'månader',
    'name'				=> 'Asset Name',
    'notes'				=> 'Anteckningar',
    'order'				=> 'Order Nummer',
    'qr'				=> 'QR-kod',
    'requestable'		=> 'Användare kan begära denna tillgång',
    'select_statustype'	=> 'Välj Statustyp',
    'serial'			=> 'Serienummer',
    'status'			=> 'Status',
    'tag'				=> 'Asset Tag',
    'update'			=> 'Asset Update',
    'warranty'			=> 'Garanti',
        'warranty_expires'		=> 'Garantin löper ut',
    'years'				=> 'år',
    'asset_location' => 'Uppdatera tillgångsplats',
    'asset_location_update_default_current' => 'Uppdatera standardplats och aktuell plats',
    'asset_location_update_default' => 'Uppdatera endast standardplats',
    'asset_not_deployable' => 'Denna tillgångs status kan inte distribueras. Denna tillgång kan inte checkas ut.',
    'asset_deployable' => 'Denna status är distribuerbar. Denna tillgång kan checkas ut.',
    'processing_spinner' => 'Bearbetar...',
];
